@@ -46,8 +46,10 @@ public:
 	bool snap_to_mebibyte( const Device & device, Partition & partition, Glib::ustring & error ) ;
 	bool snap_to_alignment( const Device & device, Partition & partition, Glib::ustring & error ) ;
 	bool apply_operation_to_disk( Operation * operation );
-	
-	bool set_disklabel( const Glib::ustring & device_path, const Glib::ustring & disklabel ) ;
+
+	bool set_disklabel( const Device & device, const Glib::ustring & disklabel );
+	bool new_disklabel( const Glib::ustring & device_path, const Glib::ustring & disklabel,
+	                    bool recreate_dmraid_devs = true );
 
 	bool toggle_flag( const Partition & partition, const Glib::ustring & flag, bool state ) ;
 	
@@ -78,6 +80,10 @@ private:
 	static void read_mountpoints_from_mount_command( std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
 	Glib::ustring get_partition_path( PedPartition * lp_partition ) ;
 	void set_device_partitions( Device & device, PedDevice* lp_device, PedDisk* lp_disk ) ;
+	void set_device_one_partition( Device & device, PedDevice * lp_device, FILESYSTEM fstype,
+	                               std::vector<Glib::ustring> & messages );
+	void set_partition_label_and_uuid( Partition & partition );
+	static FILESYSTEM recognise_filesystem_signature( PedDevice * lp_device, PedPartition * lp_partition );
 	GParted::FILESYSTEM get_filesystem( PedDevice* lp_device, PedPartition* lp_partition,
 	                                    std::vector<Glib::ustring>& messages ) ;
 	void read_label( Partition & partition ) ;
@@ -99,7 +105,7 @@ private:
 	void set_flags( Partition & partition, PedPartition* lp_partition ) ;
 	
 	//operationstuff...
-	bool create( const Device & device, Partition & new_partition, OperationDetail & operationdetail ) ;
+	bool create( Partition & new_partition, OperationDetail & operationdetail );
 	bool create_partition( Partition & new_partition, OperationDetail & operationdetail, Sector min_size = 0 ) ;
 	bool create_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
 
@@ -109,18 +115,18 @@ private:
 
 	bool remove_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
 
-	bool label_partition( const Partition & partition, OperationDetail & operation_detail ) ;
-	
+	bool label_filesystem( const Partition & partition, OperationDetail & operationdetail );
+
+	bool name_partition( const Partition & partition, OperationDetail & operationdetail );
+
 	bool change_uuid( const Partition & partition, OperationDetail & operation_detail ) ;
 
-	bool resize_move( const Device & device,
-			  const Partition & partition_old,
-			  Partition & partition_new,
-			  OperationDetail & operationdetail ) ;
-	bool move( const Device & device, 
-		   const Partition & partition_old,
-		   const Partition & partition_new,
-		   OperationDetail & operationdetail ) ;
+	bool resize_move( const Partition & partition_old,
+	                  Partition & partition_new,
+	                  OperationDetail & operationdetail );
+	bool move( const Partition & partition_old,
+	           const Partition & partition_new,
+	           OperationDetail & operationdetail );
 	bool move_filesystem( const Partition & partition_old,
 			      const Partition & partition_new,
 			      OperationDetail & operationdetail ) ;
@@ -182,6 +188,8 @@ private:
 
 	//general..	
 	bool flush_device( PedDevice * lp_device ) ;
+	bool get_device( const Glib::ustring & device_path, PedDevice *& lp_device, bool flush = false );
+	bool get_disk( PedDevice *& lp_device, PedDisk *& lp_disk, bool strict = true );
 	bool get_device_and_disk( const Glib::ustring & device_path,
 	                          PedDevice*& lp_device, PedDisk*& lp_disk, bool strict = true, bool flush = false ) ;
 	void destroy_device_and_disk( PedDevice*& lp_device, PedDisk*& lp_disk ) ;
