@@ -133,7 +133,7 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	//Create Text entry box
 	entry .set_width_chars( 20 );
 	entry .set_activates_default( true );
-	entry .set_text( partition .get_label() );
+	entry .set_text( partition.get_filesystem_label() );
 	entry .select_region( 0, entry .get_text_length() );
 	//Add entry box to table
 	table_create .attach( entry, 1, 2, 3, 4, Gtk::FILL ) ;
@@ -193,16 +193,16 @@ Partition Dialog_Partition_New::Get_New_Partition( Byte_Value sector_size )
 		new_end = selected_partition.sector_end ;
 	
 	part_temp .status = GParted::STAT_NEW ;
-	part_temp .Set(	selected_partition .device_path,
-			String::ucompose( _("New Partition #%1"), new_count ),
-			new_count, part_type,
-			FILESYSTEMS[ optionmenu_filesystem .get_history() ] .filesystem,
-			new_start, new_end,
-			sector_size,
-			selected_partition .inside_extended, false ) ;
+	part_temp.Set( selected_partition.device_path,
+	               String::ucompose( _("New Partition #%1"), new_count ),
+	               new_count, part_type, selected_partition.whole_device,
+	               FILESYSTEMS[optionmenu_filesystem.get_history()].filesystem,
+	               new_start, new_end,
+	               sector_size,
+	               selected_partition.inside_extended, false );
 
 	//Retrieve Label info
-	part_temp .set_label( Utils::trim( entry .get_text() ) ) ;
+	part_temp.set_filesystem_label( Utils::trim( entry.get_text() ) );
 	
 	//grow new partition a bit if freespaces are < 1 MiB
 	if ( (part_temp.sector_start - selected_partition.sector_start) < (MEBIBYTE / sector_size) ) 
@@ -214,11 +214,12 @@ Partition Dialog_Partition_New::Get_New_Partition( Byte_Value sector_size )
 	if ( part_temp .type == GParted::TYPE_EXTENDED )
 	{
 		Partition UNALLOCATED ;
-		UNALLOCATED .Set_Unallocated( part_temp .device_path,
-					      part_temp .sector_start,
-					      part_temp .sector_end,
-					      sector_size,
-					      true ) ;
+		UNALLOCATED.Set_Unallocated( part_temp.device_path,
+		                             part_temp.whole_device,
+		                             part_temp.sector_start,
+		                             part_temp.sector_end,
+		                             sector_size,
+		                             true );
 		part_temp .logicals .push_back( UNALLOCATED ) ;
 	}
 
