@@ -59,9 +59,9 @@ void hfsplus::read_label( Partition & partition )
 		Glib::ustring label = Utils::regexp_label( output, "ID_FS_LABEL=([^\n]*)" ) ;
 		//FIXME: find a better way to see if label is empty.. imagine someone uses 'untitled' as label.... ;)
 		if ( label != "untitled" )
-			partition .set_label( label ) ;
+			partition.set_filesystem_label( label );
 		else
-			partition .set_label( "" ) ;
+			partition.set_filesystem_label( "" );
 	}
 	else
 	{
@@ -76,10 +76,10 @@ void hfsplus::read_label( Partition & partition )
 bool hfsplus::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	Glib::ustring cmd = "";
-	if( new_partition .get_label() .empty() )
+	if( new_partition.get_filesystem_label().empty() )
 		cmd = "mkfs.hfsplus " + new_partition .get_path() ;
 	else
-		cmd = "mkfs.hfsplus -v \"" + new_partition .get_label() + "\" " + new_partition .get_path() ;
+		cmd = "mkfs.hfsplus -v \"" + new_partition.get_filesystem_label() + "\" " + new_partition.get_path();
 	return ! execute_command( cmd , operationdetail ) ;
 }
 
