@@ -74,7 +74,7 @@ void linux_swap::set_used_sectors( Partition & partition )
 {
 	if ( partition .busy )
 	{
-		T = -1 ; N = -1 ;
+		N = -1;
 		std::string line ;
 		std::ifstream input( "/proc/swaps" ) ;
 		if ( input )
@@ -85,7 +85,7 @@ void linux_swap::set_used_sectors( Partition & partition )
 			{
 				if ( line .substr( 0, path_len ) == path )
 				{
-					sscanf( line .substr( path_len ) .c_str(), " %*s %Ld %Ld", &T, &N ) ;
+					sscanf( line.substr( path_len ).c_str(), " %*s %*d %Ld", &N );
 					break ;
 				}
 			}
@@ -95,9 +95,13 @@ void linux_swap::set_used_sectors( Partition & partition )
 		{
 			partition .messages .push_back( "open(\"/proc/swaps\", O_RDONLY): " + Glib::strerror( errno ) ) ;
 		}
-		if ( T > -1 && N > -1 )
+		if ( N > -1 )
 		{
-			T = Utils::round( T * ( KIBIBYTE / double(partition .sector_size) ) ) ;
+			// Ignore swap space reported size to ignore 1 page format
+			// overhead.  Instead use partition size as sectors_fs_size so
+			// reported used figure for active swap space starts from 0
+			// upwards, matching what 'swapon -s' reports.
+			T = partition.get_sector_length();
 			N = Utils::round( N * ( KIBIBYTE / double(partition .sector_size) ) ) ;
 			partition .set_sector_usage( T, T - N ) ;
 		}
@@ -114,7 +118,7 @@ void linux_swap::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "swaplabel " + partition .get_path(), output, error, true ) )
 	{
-		partition .set_label( Utils::regexp_label( output, "^LABEL:[[:blank:]]*(.*)$" ) ) ;
+		partition.set_filesystem_label( Utils::regexp_label( output, "^LABEL:[[:blank:]]*(.*)$" ) );
 	}
 	else
 	{
@@ -128,7 +132,8 @@ void linux_swap::read_label( Partition & partition )
 
 bool linux_swap::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "swaplabel -L \"" + partition .get_label() + "\" " + partition .get_path(), operationdetail ) ;
+	return ! execute_command( "swaplabel -L \"" + partition.get_filesystem_label() + "\" " + partition.get_path(),
+	                          operationdetail );
 }
 
 void linux_swap::read_uuid( Partition & partition )
@@ -155,7 +160,9 @@ bool linux_swap::write_uuid( const Partition & partition, OperationDetail & oper
 
 bool linux_swap::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkswap -L \"" + new_partition .get_label() + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkswap -L \"" + new_partition.get_filesystem_label() + "\" " +
+	                          new_partition.get_path(),
+	                          operationdetail );
 }
 
 bool linux_swap::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
@@ -165,7 +172,7 @@ bool linux_swap::resize( const Partition & partition_new, OperationDetail & oper
 		String::ucompose( _("create new %1 file system"), Utils::get_filesystem_string( FS_LINUX_SWAP ) ) ) ) ;
 
 	//Maintain label and uuid when recreating swap
-	Glib::ustring command = "mkswap -L \"" + partition_new .get_label() + "\" " ;
+	Glib::ustring command = "mkswap -L \"" + partition_new.get_filesystem_label() + "\" ";
 	if ( ! partition_new .uuid .empty() )
 		command +=  " -U \"" + partition_new .uuid + "\" " ;
 	command += partition_new .get_path() ;
