@@ -159,7 +159,7 @@ void ntfs::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "ntfslabel --force " + partition .get_path(), output, error, false ) )
 	{
-		partition .set_label( Utils::trim( output ) ) ;
+		partition.set_filesystem_label( Utils::trim( output ) );
 	}
 	else
 	{
@@ -173,7 +173,9 @@ void ntfs::read_label( Partition & partition )
 
 bool ntfs::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "ntfslabel --force " + partition .get_path() + " \"" + partition .get_label() + "\"", operationdetail ) ;
+	return ! execute_command( "ntfslabel --force " + partition.get_path() +
+	                          " \"" + partition.get_filesystem_label() + "\"",
+	                          operationdetail );
 }
 
 void ntfs::read_uuid( Partition & partition )
@@ -192,11 +194,9 @@ bool ntfs::write_uuid( const Partition & partition, OperationDetail & operationd
 
 bool ntfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkntfs -Q -v -L \"" + new_partition.get_label() +
-				  "\" " + new_partition.get_path(),
-				  operationdetail,
-				  false,
-				  true );
+	return ! execute_command( "mkntfs -Q -v -F -L \"" + new_partition.get_filesystem_label() + "\" " +
+	                          new_partition.get_path(),
+	                          operationdetail, false, true );
 }
 
 bool ntfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
